"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var typescript_1 = require("typescript");
exports.resolveTypescriptPaths = function (options) {
    if (options === void 0) { options = {}; }
    var compilerOptions = getCompilerOptions(options.tsConfigPath);
    return {
        name: 'resolve-typescript-paths',
        resolveId: function (importee, importer) {
            if (!compilerOptions.paths || !compilerOptions.paths[importee]) {
                return null;
            }
            var resolvedModule = typescript_1.nodeModuleNameResolver(importee, importer, compilerOptions, typescript_1.sys).resolvedModule;
            if (!resolvedModule) {
                return null;
            }
            var resolvedFileName = resolvedModule.resolvedFileName;
            if (!resolvedFileName || resolvedFileName.endsWith('.d.ts')) {
                return null;
            }
            return resolvedFileName;
        },
    };
};
var getCompilerOptions = function (configPath) {
    if (configPath === void 0) { configPath = typescript_1.findConfigFile('./', typescript_1.sys.fileExists); }
    if (!configPath) {
        return {};
    }
    var configJson = typescript_1.sys.readFile(configPath);
    if (!configJson) {
        return {};
    }
    var config = JSON.parse(configJson);
    if (!config || !config.compilerOptions) {
        return {};
    }
    return config.compilerOptions;
};
